@@ -3,7 +3,7 @@ package IO::Multiplex;
 use strict;
 use warnings;
 
-our $VERSION = '1.13';
+our $VERSION = '1.14';
 
 =head1 NAME
 
@@ -386,7 +386,11 @@ sub remove
     delete $self->{_fhs}{"$fh"};
     delete $self->{_handles}{"$fh"};
     $self->_removeTimer($fh);
-    untie *$fh;
+    if (my $x = tied $fh) {
+        undef $x;
+        untie *$fh;
+    }
+    return 1;
 }
 
 =head2 set_callback_object
@@ -1105,6 +1109,6 @@ Copyright 2001-2008 Rob Brown <bbb@cpan.org>
 
 Released under the same terms as Perl itself.
 
-$Id: Multiplex.pm,v 1.36 2008/09/15 08:17:50 rob Exp $
+$Id: Multiplex.pm,v 1.40 2015/03/30 14:56:44 rob Exp $
 
 =cut
